import * as React from "react";
import styled from "styled-components";
import useScrollbarSize from "react-scrollbar-size";
import {
    AppbarAction,
    AppbarBackAction,
    AppbarContent,
    AppbarHeader,
} from "react-native-simple-elements/components/Appbar";
import useScreenSize from "react-native-simple-elements/components/Container/utils/useScreenSize";
import AuthorizedUserMenu from "../AuthorizedUserMenu";
import { MenuItemProps } from "../AuthorizedUserMenu/AuthorizedUserMenu";
import HomeIcon from "@mdi/svg/svg/home.svg";
import AccountIcon from "@mdi/svg/svg/account.svg";
import { View } from "react-native";

const HeaderContainer = styled.div({
    zIndex: 3,
});

const LeftContent = styled.div({
    width: 240,
});

type Props = {
    title?: string,
    showBackIcon?: boolean,
    backButtonIcon?: React.ReactElement,
    renderHomeAction?: (props?) => React.ReactNode,
    onHomeActionPress?: () => void,
    onBackActionPress?: () => void,
    loggedInUser?: Record<string, any>;
    isUserIconCircle?: boolean,
    shouldCheckScrollbarSize?: boolean,
    onLoginClick?: () => void,
    onViewProfileClick?: () => void,
    onLogoutClick?: () => void,
    userMenuItems?: MenuItemProps[],
    onUserMenuItemPress?: (item?) => void,
    renderDesktopLeftActions?: (props?) => React.ReactNode;
    renderDesktopContent?: (props?) => React.ReactNode;
    renderRightActions?: (props?) => React.ReactNode,
};

const defaultProps = {
    isUserIconCircle: true,
    shouldCheckScrollbarSize: false,
};

const SimpleHeader = (props: Props) => {

    const {
        title,
        renderHomeAction,
        showBackIcon,
        backButtonIcon,
        onHomeActionPress,
        onBackActionPress,
        loggedInUser,
        isUserIconCircle,
        shouldCheckScrollbarSize,
        onLoginClick,
        onViewProfileClick,
        onLogoutClick,
        userMenuItems,
        onUserMenuItemPress,
        renderDesktopLeftActions,
        renderDesktopContent,
        renderRightActions,
    } = props;

    const { isMobileView } = useScreenSize();
    const { width: scrollbarSize } = useScrollbarSize();

    const _handleBackActionPress = () => {
        if (showBackIcon) {
            if (typeof onBackActionPress === "function") {
                onBackActionPress();
            }
        } else {
            if (typeof onHomeActionPress === "function") {
                onHomeActionPress();
            }
        }
    };

    const _handleLoginClick = () => {
        if (typeof onLoginClick === "function") {
            onLoginClick();
        }
    };

    return (
        <HeaderContainer
            style={{
                marginRight: shouldCheckScrollbarSize ? scrollbarSize || 0 : 0,
            }}
        >
            <AppbarHeader>
                {isMobileView ?
                    <>
                        {renderHomeAction ? renderHomeAction() :
                            <AppbarBackAction
                                icon={showBackIcon ? backButtonIcon : HomeIcon}
                                onPress={_handleBackActionPress}
                            />
                        }
                        <AppbarContent
                            title={title}
                        />
                    </>
                    :
                    null
                }
                {!isMobileView ? renderDesktopLeftActions ?
                    <>
                        <LeftContent>
                            {renderDesktopLeftActions ? renderDesktopLeftActions() : null}
                        </LeftContent>
                    </>
                    :
                    <AppbarBackAction
                        icon={HomeIcon}
                    />
                    :
                    null
                }
                {!isMobileView ? renderDesktopContent ?
                    renderDesktopContent()
                    :
                    <View
                        style={{
                            flex: 1,
                        }}
                    >
                    </View>
                    :
                    null
                }
                {renderRightActions ? renderRightActions() : null}
                {loggedInUser?.userId ?
                    <AuthorizedUserMenu
                        circle={isUserIconCircle}
                        loggedInUser={loggedInUser}
                        onViewProfileClick={onViewProfileClick}
                        onLogoutClick={onLogoutClick}
                        userMenuItems={userMenuItems}
                        onUserMenuItemPress={onUserMenuItemPress}
                    /> :
                    <AppbarAction
                        icon={AccountIcon}
                        onPress={_handleLoginClick}
                    />
                }
            </AppbarHeader>
        </HeaderContainer>
    );
};

SimpleHeader.defaultProps = defaultProps;

export default SimpleHeader;
